@@ -20,7 +20,7 @@ class BackupFile:
 
     base_prefix = ''
     file_path = ''
-    exclude_patterns = ()
+    exclude_patterns: tuple[str, ...] = ()
 
     # Scrub old files after after file limit exceeded
     scrub_local_files = True
