@@ -6,17 +6,18 @@ from ..typehints import INTERVALS
 
 
 @task
-def backup(ctx: Context) -> None:
+def backup(ctx: Context) -> bool:
     """
     Backup all contents of the /config directory
     """
-    print(f'Backing up {BackupDBOSConfig.directory}... ', end='', flush=True)
+    print('Backup contents of the /config directory... ', end='', flush=True)
     BackupDBOSConfig(ctx, filename='dbos.tbz2').process()
     print('Done')
+    return True
 
 
 @task(help={'interval': 'File archive interval - (hourly, daily, weekly, monthly)'})
-def backup_files(ctx: Context, interval: INTERVALS = '') -> None:
+def backup_files(ctx: Context, interval: INTERVALS = '') -> bool:
     """
     Show DrawBridgeOS config backup files for specified interval.
     """
@@ -27,6 +28,7 @@ def backup_files(ctx: Context, interval: INTERVALS = '') -> None:
         for bf in db_backups:
             print(bf)
         print()
+    return True
 
 
 @task(
